import { FC } from 'react';
import { Column as ColumnType, Option as OptionType, Theme } from '../../types';
interface ContainerProps {
    /**
     * The currently selected option.
     */
    current: OptionType;
    /**
     * The function to set the current option.
     */
    select: (option: OptionType) => void;
    /**
     * The function to select an option.
     */
    add: () => void;
    /**
     * The function to remove a selected option.
     */
    remove: () => void;
    /**
     * The function to select all options.
     */
    addAll: () => void;
    /**
     * The function to remove all selected options.
     */
    removeAll: () => void;
    /**
     * The available select options.
     */
    options: OptionType[];
    /**
     * The selected options.
     */
    selected: OptionType[];
    /**
     * The function to go to next option.
     */
    onNext: (column: ColumnType) => void;
    /**
     * The function to go to previous option.
     */
    onPrevious: (column: ColumnType) => void;
    /**
     * Disable double clicking to add/remove a list option.
     */
    disableDoubleClick: boolean;
    /**
     * Disable keyboard navigation between list options.
     */
    disableKeyboard: boolean;
    /**
     * The react-column-select theme object.
     */
    theme: Theme;
}
declare const Container: FC<ContainerProps>;
export default Container;
